﻿'---------------------------------------------------------------------------
' -= UpdateLastRecordInDB.vb =-
'---------------------------------------------------------------------------
' Author    : Jeffrey
' Date      : 07-06-2010
' Version   : 0.1
' URL       : http://www.domoticaforum.eu/
'
'---------------------------------------
'   Description
'---------------------------------------
' Updates last record in table (Access Database (.MDB))
'
'---------------------------------------
'   Usage
'---------------------------------------
' UpdateLastRecordInDB.vb("Main","<PATH_TO_MDB>;<TABLE>;<FIELDTOSORTON>;<FIELDNAME>;<FIELDVALUE>;<FIELDNAME>;<FIELDVALUE>") 
'
'---------------------------------------
'   Mandatory Parameters
'---------------------------------------
' <PATH_TO_MDB>     The full path to the database file.
' <TABLE>           The table to write to
' <FIELDTOSORTON>   The field that is used to get the last record (usually the primarykey field which has an autonumbered type on it)
' <FIELDNAME>       The first fieldname.
' <FIELDVALUE>      The first fieldvalue.
'
'---------------------------------------
'   Optional Parameters
'---------------------------------------
' <FIELDNAME>    Additional fieldname
' <FIELDVALUE>   Additional fieldvalue
'
'---------------------------------------
'   Variables
'---------------------------------------
' @date         Replaces @date with the current date
' @time         Replaces @time with the current time
'
'---------------------------------------
'   Example
'---------------------------------------
' UpdateLastRecordInDB.vb("Main","C:\Program Files\Homeseer HSPRO\Data\Temperature\Temperature.mdb;Temperature;ID;sensorDate;07-06-2010;sensorTime;16:10:00;sensorValue;22,1;sensorCode;/2")
'
'---------------------------------------------------------------------------
'   Changelog
'---------------------------------------------------------------------------
' Version    Date            Reason              Changes
'---------------------------------------------------------------------------
' 0.1        07-06-2010      Initial version     None
'---------------------------------------------------------------------------
Public Sub Main(ByVal parm As Object)
    Dim aParameter() As String
    Dim bDebug As Boolean
    Const cScriptname As String = "UpdateLastRecordInDB"
    Const cScriptversion As String = "0.1"

    Dim sFieldsValues As String = ""

    'ENABLE/DISABLE DEBUG MESSAGING TO HOMESEER
    bDebug = False 'Only enable for troubleshooting

    If bDebug Then hs.WriteLog("Debug", cScriptname & " " & cScriptversion & " - ----- Started -----")

    'GET PARAMETERS
    If Not InStr(parm.ToString, ";") > 0 Then
        hs.WriteLog("Error", "<font color=red>" & cScriptname & " " & cScriptversion & " - Script aborted: Required parameters not specified.</font>")
        Exit Sub
    End If
    aParameter = Split(parm.ToString, ";", -1, CType(1, CompareMethod))
    If UBound(aParameter) < 2 Then
        hs.WriteLog("Error", "<font color=red>" & cScriptname & " " & cScriptversion & " - Script aborted: Required parameters not specified. aParameter <2 </font>")
        Exit Sub
    End If
    Dim WriteDate As Date = DateValue(CStr(Now))
    Dim WriteTime As Date = TimeValue(CStr(Now))
    If bDebug Then hs.WriteLog("Debug", cScriptname & " " & cScriptversion & " - WriteDate = " & WriteDate)
    If bDebug Then hs.WriteLog("Debug", cScriptname & " " & cScriptversion & " - WriteTime = " & WriteTime)
    Dim sDatabase As String = aParameter(0)
    If bDebug Then hs.WriteLog("Debug", cScriptname & " " & cScriptversion & " - sDatabase = " & sDatabase)
    Dim sTable As String = aParameter(1)
    If bDebug Then hs.WriteLog("Debug", cScriptname & " " & cScriptversion & " - sTable = " & sTable)
    Dim sFieldToSortOn As String = aParameter(2)
    If bDebug Then hs.WriteLog("Debug", cScriptname & " " & cScriptversion & " - sFieldToSortOn = " & sFieldToSortOn)

    'GET FIELDNAMES AND VALUES FROM PARAMETERARRAY
    For i As Integer = 3 To UBound(aParameter) Step 2
        If bDebug Then hs.WriteLog("Debug", cScriptname & " " & cScriptversion & " - aParameter index " & i & " field = " & aParameter(i) & " value = " & aParameter(i + 1))
        If InStr(LCase(aParameter(i + 1)), "@date") Then
            If bDebug Then hs.WriteLog("Debug", cScriptname & " " & cScriptversion & " - aParameter index " & i + 1 & " @date found ")
            aParameter(i + 1) = WriteDate
        End If
        If InStr(LCase(aParameter(i + 1)), "@time") Then
            If bDebug Then hs.WriteLog("Debug", cScriptname & " " & cScriptversion & " - aParameter index " & i + 1 & " @time found ")
            aParameter(i + 1) = WriteTime
        End If
        sFieldsValues = sFieldsValues & ", " & aParameter(i) & "='" & aParameter(i + 1) & "'"
    Next
    'CLEANUP STRING
    sFieldsValues = Mid(sFieldsValues, 2)
    If bDebug Then hs.WriteLog("Debug", cScriptname & " " & cScriptversion & " - sFieldsValues = " & sFieldsValues)

    'UPDATE THE RECORD
    Dim oConn As Object = CreateObject("ADODB.Connection")
    oConn.Open("Provider=Microsoft.Jet.OLEDB.4.0; Data Source=" & sDatabase)
    Dim sSql As String = "UPDATE " & sTable & " SET " & sFieldsValues & " WHERE " & sFieldToSortOn & " in (SELECT TOP 1 " & sFieldToSortOn & " FROM " & sTable & " ORDER BY " & sFieldToSortOn & " DESC)"
    If bDebug Then hs.WriteLog("Debug", cScriptname & " " & cScriptversion & " - SQL Statement = " & sSql)
    oConn.execute(sSql)
    oConn.close()
    oConn = Nothing
    If bDebug Then hs.WriteLog("Debug", cScriptname & " " & cScriptversion & " - ----- Ended -----")
End Sub
