﻿'---------------------------------------------------------------------------
' -= WriteToDB.vb =-
'---------------------------------------------------------------------------
' Author    : Jeffrey
' Date      : 05-01-2010
' Version   : 0.5
' URL       : http://www.domoticaforum.eu/
'
'---------------------------------------
'   Description
'---------------------------------------
' Writes a record to a Access Database (.MDB)
'
'---------------------------------------
'   Usage
'---------------------------------------
' WriteToDB.vb("Main","<PATH_TO_MDB>;<TABLE>;<FIELDNAME>;<FIELDVALUE>;<FIELDNAME>;<FIELDVALUE>") 
'
'---------------------------------------
'   Mandatory Parameters
'---------------------------------------
' <PATH_TO_MDB>  The full path to the database file.
' <TABLE>        The table to write to
' <FIELDNAME>    The first fieldname.
' <FIELDVALUE>   The first fieldvalue.
'
'---------------------------------------
'   Optional Parameters
'---------------------------------------
' <FIELDNAME>    Additional fieldname
' <FIELDVALUE>   Additional fieldvalue
'
'---------------------------------------
'   Variables
'---------------------------------------
' @date         Replaces @date with the current date
' @time         Replaces @time with the current time
'
'---------------------------------------
'   Example
'---------------------------------------
' WriteToDB.vb("Main","C:\Program Files\Homeseer HSPRO\Data\Temperature\Temperature.mdb;Temperature;sensorDate;02-01-2010;sensorTime;16:10:00;sensorValue;22,1;sensorCode;/2")
'
'---------------------------------------------------------------------------
'   Changelog
'---------------------------------------------------------------------------
' Version    Date            Reason              Changes
'---------------------------------------------------------------------------
' 0.1        02-01-2010      Initial version     None
' 0.5        05-01-2010      Bugs Fixed          -
'---------------------------------------------------------------------------
Public Sub Main(ByVal parm As Object)
    Dim aParameter() As String
    Dim bDebug As Boolean
    Const cScriptname As String = "WriteToDb"
    Const cScriptversion As String = "0.5"

    Dim sFields As String = ""
    Dim sValues As String = ""

    'ENABLE/DISABLE DEBUG MESSAGING TO HOMESEER
    bDebug = False 'Only enable for troubleshooting

    If bDebug Then hs.WriteLog("Debug", cScriptname & " " & cScriptversion & " - Started")

    'GET PARAMETERS
    If Not InStr(parm.ToString, ";") > 0 Then
        hs.WriteLog("Error", "<font color=red>" & cScriptname & " " & cScriptversion & " - Script aborted: Required parameters not specified.</font>")
        Exit Sub
    End If
    aParameter = Split(parm.ToString, ";", -1, CType(1, CompareMethod))
    If UBound(aParameter) < 2 Then
        hs.WriteLog("Error", "<font color=red>" & cScriptname & " " & cScriptversion & " - Script aborted: Required parameters not specified. aParameter <2 </font>")
        Exit Sub
    End If
    Dim WriteDate As Date = DateValue(CStr(Now))
    Dim WriteTime As Date = TimeValue(CStr(Now))
    If bDebug Then hs.WriteLog("Debug", cScriptname & " " & cScriptversion & " - WriteDate = " & WriteDate)
    If bDebug Then hs.WriteLog("Debug", cScriptname & " " & cScriptversion & " - WriteTime = " & WriteTime)
    Dim sDatabase As String = aParameter(0)
    If bDebug Then hs.WriteLog("Debug", cScriptname & " " & cScriptversion & " - sDatabase = " & sDatabase)
    Dim sTable As String = aParameter(1)
    If bDebug Then hs.WriteLog("Debug", cScriptname & " " & cScriptversion & " - sTable = " & sTable)

    'GET FIELDNAMES AND VALUES FROM PARAMETERARRAY
    Dim bParametersEven As Boolean = True
    For i As Integer = 2 To UBound(aParameter)
        If bDebug Then hs.WriteLog("Debug", cScriptname & " " & cScriptversion & " - aParameter index " & i & " value = " & aParameter(i))
        If bParametersEven = True Then 'Even are fields
            sValues = sValues & ", " & aParameter(i)
            bParametersEven = False
        Else
            If InStr(LCase(aParameter(i)), "@date") Then
                If bDebug Then hs.WriteLog("Debug", cScriptname & " " & cScriptversion & " - aParameter index " & i & " @date found ")
                aParameter(i) = WriteDate
            End If    
            If InStr(LCase(aParameter(i)), "@time") Then 
                If bDebug Then hs.WriteLog("Debug", cScriptname & " " & cScriptversion & " - aParameter index " & i & " @time found ")
                aParameter(i) = WriteTime
            End If
            sFields = sFields & "','" & aParameter(i)
            bParametersEven = True 'Uneven are values
        End If
    Next

    'STRIP SOME LEFT OVER CHARACTERS
    sFields = Mid(sFields, 3) & "'"
    sValues = Mid(sValues, 3)
    If bDebug Then
        hs.WriteLog("Debug", cScriptname & " " & cScriptversion & " - sFields = " & sFields)
        hs.WriteLog("Debug", cScriptname & " " & cScriptversion & " - sValues = " & sValues)
    End If

    'ADD THE RECORD TO THE DATABASE
    Dim oConn As Object = CreateObject("ADODB.Connection")
    oConn.Open("Provider=Microsoft.Jet.OLEDB.4.0; Data Source=" & sDatabase)
    Dim sSql As String = "insert into " & sTable & " (" & sValues & ") values (" & sFields & ")"
    If bDebug Then hs.WriteLog("Debug", cScriptname & " " & cScriptversion & " - SQL Statement = " & sSql)
    oConn.execute(sSql)
    oConn.close()
    oConn = Nothing
End Sub
